# awesome bash cli (abcli/abc)

![image](./assets/marquee.png)

`abcli` 🚀 is an implementation of [🔻 giza](https://github.com/kamangir/giza) and the library behind [these projects](https://github.com/kamangir/kamangir).

To install `abcli` follow the instructions for:

- [Amazon EC2 instances](https://github.com/kamangir/awesome-bash-cli/wiki/ec2)
- [Amazon SageMaker](https://github.com/kamangir/blue-plugin/blob/main/SageMaker.md)
- [Jetson Nano](https://github.com/kamangir/awesome-bash-cli/wiki/Jetson-Nano)
- [macOS](https://github.com/kamangir/awesome-bash-cli/wiki/macOS)
- [Raspberry Pi](https://github.com/kamangir/awesome-bash-cli/wiki/Raspberry-Pi)

To see the list of `abcli` commands type in:

```
abcli ?
```

To configure `abcli` complete the [.env](./.env) file using this [sample](./sample.env).

## branches

- [current](.) active branch.
- [main](https://github.com/kamangir/awesome-bash-cli/tree/main) running on Raspberry pis, do not touch. ⚠️
